@@ -9,18 +9,22 @@ from labext.modules.jquery import JQuery
 
 
 class DataTable(Module):
-    args = {
+    py_args = {
         "index": True,
         "escape": True,
         "border": 0,
         "justify": "left",
         "classes": ['table', 'table-striped', 'table-bordered'],
-        "length_menu": [10, 25, 50, -1]
     }
+    js_args = {}
 
     @classmethod
     def set_args(cls, **kwargs):
-        cls.args.update(**kwargs)
+        cls.py_args.update(**kwargs)
+
+    @classmethod
+    def set_js_args(cls, **kwargs):
+        cls.js_args.update(**kwargs)
 
     @classmethod
     def id(cls) -> str:
@@ -28,7 +32,7 @@ class DataTable(Module):
 
     @classmethod
     def css(cls) -> List[str]:
-        return ["//cdn.datatables.net/1.10.19/css/jquery.dataTables.min.css"]
+        return ["//cdn.datatables.net/1.10.19/css/jquery.dataTables.min.css", f"/custom/labext/{cls.id()}/css/jupyter_data_tables.css"]
 
     @classmethod
     def js(cls) -> Dict[str, str]:
@@ -40,6 +44,15 @@ class DataTable(Module):
 
     @classmethod
     def register(cls, use_local: bool = True):
+        localdir = cls.get_local_dir()
+        custom_css_file = localdir / "css/jupyter_data_tables.css"
+        if not custom_css_file.exists():
+            with open(str(custom_css_file), "w") as f:
+                f.write("""
+.jupyter-widgets {
+    overflow: auto !important
+}""")
+
         super().register(use_local)
 
         import pandas as pd
@@ -48,17 +61,14 @@ class DataTable(Module):
             # create table DOM
             # script = f'$(element).html(`{self.to_html(**cls.args)}`);\n'
             # execute jQuery to turn table into DataTable
-            html = self.to_html(**{k: v for k, v in cls.args.items() if k != "length_menu"})
-            length_menu = json.dumps([cls.args['length_menu'], ["All" if x == -1 else x for x in cls.args['length_menu']]])
+            html = self.to_html(**cls.py_args)
 
             script = f"""
 require(["{cls.id()}", "{JQuery.id()}"], function(dataTables, jquery) {{
     jquery(element).html(`{html}`);
     jquery(document).ready( () => {{
         // Turn existing table into datatable
-        jquery(element).find("table.dataframe").DataTable({{
-            "lengthMenu": {length_menu}
-        }});
+        jquery(element).find("table.dataframe").DataTable({json.dumps(cls.js_args)});
     }})
 }});"""
             return script
@@ -68,8 +78,8 @@ require(["{cls.id()}", "{JQuery.id()}"], function(dataTables, jquery) {{
     @classmethod
     def download(cls):
         localdir = super().download()
-        (Path(localdir) / "images").mkdir(exist_ok=True)
+        (localdir / "images").mkdir(exist_ok=True)
 
         for static_file in ["sort_asc.png", "sort_both.png"]:
-            with open(os.path.join(localdir, "images", static_file), "wb") as f:
+            with open(str(localdir / "images" / static_file), "wb") as f:
                 f.write(requests.get(f"https://cdn.datatables.net/1.10.19/images/{static_file}").content)
