@@ -1,3 +1,3 @@
 import labext.modules as M
 import labext.widgets as W
-import labext.interactive_funcs as F
+import labext.apps as A
